![BVlain_logo](bvlain/BVlain_logo.png)

BVlain is the module for bond valence site energy calculations and is about to solve tasks related to ionic conductivity of a tracer ion in a crystal structure.

